@@ -1,7 +1,8 @@
 from .core_experiment import (get_configs_ready,
                               get_extra_cmd_line_input,
                               set_random_seeds,
-                              determine_resource)
+                              determine_resource,
+                              ask_for_resource_to_run)
 from .core_files_load import (load_mle_toolbox_config,
                               load_yaml_config,
                               load_json_config,
@@ -9,8 +10,8 @@ from .core_files_load import (load_mle_toolbox_config,
                               load_result_logs)
 from .core_files_merge import merge_hdf5_files
 from .mle_logger import MLE_Logger
-from .load_meta_log import load_meta_log, subselect_meta_log
-from .load_hyper_log import load_hyper_log, subselect_hyper_log
+from .load_meta_log import load_meta_log
+from .load_hyper_log import load_hyper_log
 from .load_model import load_model_ckpt
 from .helpers import (print_framed,
                       get_jax_os_ready,
@@ -22,6 +23,7 @@ __all__ = [
            'load_json_config',
            'load_pkl_object',
            'determine_resource',
+           'ask_for_resource_to_run',
            'print_framed',
            'get_jax_os_ready',
            'MLE_Logger',
@@ -30,8 +32,6 @@ __all__ = [
            'set_random_seeds',
            'load_result_logs'
            'load_meta_log',
-           'subselect_meta_log',
-           'subselect_hyper_log',
            'load_hyper_log',
            'load_model_ckpt'
            ]
